@@ -20,7 +20,7 @@ from collections import namedtuple
 import pytest
 import sys
 
-from abp.filters.rpy import tuple2dict, line2dict, lines2dicts
+from abp.filters.rpy import line2dict, lines2dicts
 
 
 _SAMPLE_TUPLE = namedtuple('tuple', 'foo,bar')
@@ -68,7 +68,18 @@ _TEST_EXAMPLES = {
             b'text': b'foo.com##div#ad1',
             b'selector': {b'type': b'css', b'value': b'div#ad1'},
             b'action': b'hide',
-            b'options': [(b'domain', [(b'foo.com', True)])],
+            b'options': {b'domain': {b'foo.com': True}},
+        },
+    },
+    'filter_with_%': {
+        'in': b'%22banner%*%22idzone%',
+        'out': {
+            b'type': b'Filter',
+            b'text': b'%22banner%*%22idzone%',
+            b'selector': {b'type': b'url-pattern',
+                          b'value': b'%22banner%*%22idzone%'},
+            b'action': b'block',
+            b'options': {},
         },
     },
     'filter_multiple': {
@@ -78,8 +89,22 @@ _TEST_EXAMPLES = {
             b'text': b'foo.com,bar.com##div#ad1',
             b'selector': {b'type': b'css', b'value': b'div#ad1'},
             b'action': b'hide',
-            b'options': [(b'domain', [(b'foo.com', True), (b'bar.com',
-                                                           True)])],
+            b'options': {b'domain': {b'foo.com': True, b'bar.com': True}},
+        },
+    },
+    'filter_with_sitekey_list': {
+        'in': b'@@bla$ping,domain=foo.com|~bar.foo.com,sitekey=foo|bar',
+        'out': {
+            b'text':
+                b'@@bla$ping,domain=foo.com|~bar.foo.com,sitekey=foo|bar',
+                b'selector': {b'value': b'bla', b'type': b'url-pattern'},
+                b'action': b'allow',
+                b'options': {
+                    b'ping': True,
+                    b'domain': {b'foo.com': True,
+                                b'bar.foo.com': False},
+                    b'sitekey': [b'foo', b'bar']},
+                b'type': b'Filter',
         },
     },
 }
@@ -110,21 +135,6 @@ def check_data_utf8(data):
         raise AssertionError('{} is str. Expected bytes.'.format(data))
 
 
-@pytest.mark.parametrize('foo,bar', [
-    ('test_foo', 1),
-    ({'foofoo': 'test', 'foobar': 2}, [1, 2, 3]),
-    ((1,), [('a', True), ('b', False)]),
-])
-def test_tuple2dict(foo, bar):
-    """Test that dicts are produced correctly from a named tuple."""
-    data = _SAMPLE_TUPLE(foo=foo, bar=bar)
-    exp = {'foo': foo, 'bar': bar, 'type': 'tuple'}
-
-    result = tuple2dict(data)
-
-    assert exp == result
-
-
 @pytest.mark.skipif(sys.version.startswith('3.'), reason='Redundant on py3+.')
 @pytest.mark.parametrize('line_type', _TEST_EXAMPLES.keys())
 def test_line2dict_encoding(line_type):
